# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'SentryDashboardWidgetArgs',
    'SentryDashboardWidgetArgsDict',
    'SentryDashboardWidgetLayoutArgs',
    'SentryDashboardWidgetLayoutArgsDict',
    'SentryDashboardWidgetQueryArgs',
    'SentryDashboardWidgetQueryArgsDict',
    'SentryMetricAlertTriggerArgs',
    'SentryMetricAlertTriggerArgsDict',
    'SentryMetricAlertTriggerActionArgs',
    'SentryMetricAlertTriggerActionArgsDict',
]

MYPY = False

if not MYPY:
    class SentryDashboardWidgetArgsDict(TypedDict):
        display_type: pulumi.Input[str]
        layout: pulumi.Input['SentryDashboardWidgetLayoutArgsDict']
        queries: pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetQueryArgsDict']]]
        title: pulumi.Input[str]
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of this resource.
        """
        interval: NotRequired[pulumi.Input[str]]
        limit: NotRequired[pulumi.Input[int]]
        widget_type: NotRequired[pulumi.Input[str]]
elif False:
    SentryDashboardWidgetArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SentryDashboardWidgetArgs:
    def __init__(__self__, *,
                 display_type: pulumi.Input[str],
                 layout: pulumi.Input['SentryDashboardWidgetLayoutArgs'],
                 queries: pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetQueryArgs']]],
                 title: pulumi.Input[str],
                 id: Optional[pulumi.Input[str]] = None,
                 interval: Optional[pulumi.Input[str]] = None,
                 limit: Optional[pulumi.Input[int]] = None,
                 widget_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] id: The ID of this resource.
        """
        pulumi.set(__self__, "display_type", display_type)
        pulumi.set(__self__, "layout", layout)
        pulumi.set(__self__, "queries", queries)
        pulumi.set(__self__, "title", title)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if limit is not None:
            pulumi.set(__self__, "limit", limit)
        if widget_type is not None:
            pulumi.set(__self__, "widget_type", widget_type)

    @property
    @pulumi.getter(name="displayType")
    def display_type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "display_type")

    @display_type.setter
    def display_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_type", value)

    @property
    @pulumi.getter
    def layout(self) -> pulumi.Input['SentryDashboardWidgetLayoutArgs']:
        return pulumi.get(self, "layout")

    @layout.setter
    def layout(self, value: pulumi.Input['SentryDashboardWidgetLayoutArgs']):
        pulumi.set(self, "layout", value)

    @property
    @pulumi.getter
    def queries(self) -> pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetQueryArgs']]]:
        return pulumi.get(self, "queries")

    @queries.setter
    def queries(self, value: pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetQueryArgs']]]):
        pulumi.set(self, "queries", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[str]:
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter
    def limit(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "limit")

    @limit.setter
    def limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "limit", value)

    @property
    @pulumi.getter(name="widgetType")
    def widget_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "widget_type")

    @widget_type.setter
    def widget_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "widget_type", value)


if not MYPY:
    class SentryDashboardWidgetLayoutArgsDict(TypedDict):
        h: pulumi.Input[int]
        min_h: pulumi.Input[int]
        w: pulumi.Input[int]
        x: pulumi.Input[int]
        y: pulumi.Input[int]
elif False:
    SentryDashboardWidgetLayoutArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SentryDashboardWidgetLayoutArgs:
    def __init__(__self__, *,
                 h: pulumi.Input[int],
                 min_h: pulumi.Input[int],
                 w: pulumi.Input[int],
                 x: pulumi.Input[int],
                 y: pulumi.Input[int]):
        pulumi.set(__self__, "h", h)
        pulumi.set(__self__, "min_h", min_h)
        pulumi.set(__self__, "w", w)
        pulumi.set(__self__, "x", x)
        pulumi.set(__self__, "y", y)

    @property
    @pulumi.getter
    def h(self) -> pulumi.Input[int]:
        return pulumi.get(self, "h")

    @h.setter
    def h(self, value: pulumi.Input[int]):
        pulumi.set(self, "h", value)

    @property
    @pulumi.getter(name="minH")
    def min_h(self) -> pulumi.Input[int]:
        return pulumi.get(self, "min_h")

    @min_h.setter
    def min_h(self, value: pulumi.Input[int]):
        pulumi.set(self, "min_h", value)

    @property
    @pulumi.getter
    def w(self) -> pulumi.Input[int]:
        return pulumi.get(self, "w")

    @w.setter
    def w(self, value: pulumi.Input[int]):
        pulumi.set(self, "w", value)

    @property
    @pulumi.getter
    def x(self) -> pulumi.Input[int]:
        return pulumi.get(self, "x")

    @x.setter
    def x(self, value: pulumi.Input[int]):
        pulumi.set(self, "x", value)

    @property
    @pulumi.getter
    def y(self) -> pulumi.Input[int]:
        return pulumi.get(self, "y")

    @y.setter
    def y(self, value: pulumi.Input[int]):
        pulumi.set(self, "y", value)


if not MYPY:
    class SentryDashboardWidgetQueryArgsDict(TypedDict):
        aggregates: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        columns: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        conditions: NotRequired[pulumi.Input[str]]
        field_aliases: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        fields: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of this resource.
        """
        name: NotRequired[pulumi.Input[str]]
        order_by: NotRequired[pulumi.Input[str]]
elif False:
    SentryDashboardWidgetQueryArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SentryDashboardWidgetQueryArgs:
    def __init__(__self__, *,
                 aggregates: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 conditions: Optional[pulumi.Input[str]] = None,
                 field_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order_by: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] id: The ID of this resource.
        """
        if aggregates is not None:
            pulumi.set(__self__, "aggregates", aggregates)
        if columns is not None:
            pulumi.set(__self__, "columns", columns)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if field_aliases is not None:
            pulumi.set(__self__, "field_aliases", field_aliases)
        if fields is not None:
            pulumi.set(__self__, "fields", fields)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if order_by is not None:
            pulumi.set(__self__, "order_by", order_by)

    @property
    @pulumi.getter
    def aggregates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "aggregates")

    @aggregates.setter
    def aggregates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "aggregates", value)

    @property
    @pulumi.getter
    def columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "columns")

    @columns.setter
    def columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "columns", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="fieldAliases")
    def field_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "field_aliases")

    @field_aliases.setter
    def field_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "field_aliases", value)

    @property
    @pulumi.getter
    def fields(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "fields")

    @fields.setter
    def fields(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "fields", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "order_by")

    @order_by.setter
    def order_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "order_by", value)


if not MYPY:
    class SentryMetricAlertTriggerArgsDict(TypedDict):
        alert_threshold: pulumi.Input[float]
        label: pulumi.Input[str]
        threshold_type: pulumi.Input[int]
        actions: NotRequired[pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerActionArgsDict']]]]
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of this resource.
        """
        resolve_threshold: NotRequired[pulumi.Input[float]]
elif False:
    SentryMetricAlertTriggerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SentryMetricAlertTriggerArgs:
    def __init__(__self__, *,
                 alert_threshold: pulumi.Input[float],
                 label: pulumi.Input[str],
                 threshold_type: pulumi.Input[int],
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerActionArgs']]]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 resolve_threshold: Optional[pulumi.Input[float]] = None):
        """
        :param pulumi.Input[str] id: The ID of this resource.
        """
        pulumi.set(__self__, "alert_threshold", alert_threshold)
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "threshold_type", threshold_type)
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if resolve_threshold is not None:
            pulumi.set(__self__, "resolve_threshold", resolve_threshold)

    @property
    @pulumi.getter(name="alertThreshold")
    def alert_threshold(self) -> pulumi.Input[float]:
        return pulumi.get(self, "alert_threshold")

    @alert_threshold.setter
    def alert_threshold(self, value: pulumi.Input[float]):
        pulumi.set(self, "alert_threshold", value)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[str]:
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> pulumi.Input[int]:
        return pulumi.get(self, "threshold_type")

    @threshold_type.setter
    def threshold_type(self, value: pulumi.Input[int]):
        pulumi.set(self, "threshold_type", value)

    @property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerActionArgs']]]]:
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SentryMetricAlertTriggerActionArgs']]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="resolveThreshold")
    def resolve_threshold(self) -> Optional[pulumi.Input[float]]:
        return pulumi.get(self, "resolve_threshold")

    @resolve_threshold.setter
    def resolve_threshold(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "resolve_threshold", value)


if not MYPY:
    class SentryMetricAlertTriggerActionArgsDict(TypedDict):
        target_type: pulumi.Input[str]
        type: pulumi.Input[str]
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of this resource.
        """
        integration_id: NotRequired[pulumi.Input[int]]
        target_identifier: NotRequired[pulumi.Input[str]]
elif False:
    SentryMetricAlertTriggerActionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SentryMetricAlertTriggerActionArgs:
    def __init__(__self__, *,
                 target_type: pulumi.Input[str],
                 type: pulumi.Input[str],
                 id: Optional[pulumi.Input[str]] = None,
                 integration_id: Optional[pulumi.Input[int]] = None,
                 target_identifier: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] id: The ID of this resource.
        """
        pulumi.set(__self__, "target_type", target_type)
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if integration_id is not None:
            pulumi.set(__self__, "integration_id", integration_id)
        if target_identifier is not None:
            pulumi.set(__self__, "target_identifier", target_identifier)

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "target_type")

    @target_type.setter
    def target_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "target_type", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "integration_id")

    @integration_id.setter
    def integration_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "integration_id", value)

    @property
    @pulumi.getter(name="targetIdentifier")
    def target_identifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "target_identifier")

    @target_identifier.setter
    def target_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_identifier", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryTeamArgs', 'SentryTeam']

@pulumi.input_type
class SentryTeamArgs:
    def __init__(__self__, *,
                 organization: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SentryTeam resource.
        :param pulumi.Input[str] organization: The slug of the organization the team should be created for.
        :param pulumi.Input[str] name: The name of the team.
        :param pulumi.Input[str] slug: The optional slug for this team.
        """
        pulumi.set(__self__, "organization", organization)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the team should be created for.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the team.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The optional slug for this team.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)


@pulumi.input_type
class _SentryTeamState:
    def __init__(__self__, *,
                 has_access: Optional[pulumi.Input[bool]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 is_member: Optional[pulumi.Input[bool]] = None,
                 is_pending: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 team_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SentryTeam resources.
        :param pulumi.Input[str] internal_id: The internal ID for this team.
        :param pulumi.Input[str] name: The name of the team.
        :param pulumi.Input[str] organization: The slug of the organization the team should be created for.
        :param pulumi.Input[str] slug: The optional slug for this team.
        :param pulumi.Input[str] team_id: Use `internal_id` instead.
        """
        if has_access is not None:
            pulumi.set(__self__, "has_access", has_access)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if is_member is not None:
            pulumi.set(__self__, "is_member", is_member)
        if is_pending is not None:
            pulumi.set(__self__, "is_pending", is_pending)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if team_id is not None:
            warnings.warn("""Use `internal_id` instead.""", DeprecationWarning)
            pulumi.log.warn("""team_id is deprecated: Use `internal_id` instead.""")
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @property
    @pulumi.getter(name="hasAccess")
    def has_access(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "has_access")

    @has_access.setter
    def has_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "has_access", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this team.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter(name="isMember")
    def is_member(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_member")

    @is_member.setter
    def is_member(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_member", value)

    @property
    @pulumi.getter(name="isPending")
    def is_pending(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_pending")

    @is_pending.setter
    def is_pending(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_pending", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the team.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the team should be created for.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The optional slug for this team.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter(name="teamId")
    @_utilities.deprecated("""Use `internal_id` instead.""")
    def team_id(self) -> Optional[pulumi.Input[str]]:
        """
        Use `internal_id` instead.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team_id", value)


class SentryTeam(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Sentry Team resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a team
        default = sentry.SentryTeam("default",
            organization="my-organization",
            name="my-team",
            slug="my-team")
        ```

        ## Import

        import using the organization and team slugs from the URL:

        https://sentry.io/settings/[org-slug]/teams/[team-slug]/members/

        ```sh
        $ pulumi import sentry:index/sentryTeam:SentryTeam default org-slug/team-slug
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the team.
        :param pulumi.Input[str] organization: The slug of the organization the team should be created for.
        :param pulumi.Input[str] slug: The optional slug for this team.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryTeamArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Team resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a team
        default = sentry.SentryTeam("default",
            organization="my-organization",
            name="my-team",
            slug="my-team")
        ```

        ## Import

        import using the organization and team slugs from the URL:

        https://sentry.io/settings/[org-slug]/teams/[team-slug]/members/

        ```sh
        $ pulumi import sentry:index/sentryTeam:SentryTeam default org-slug/team-slug
        ```

        :param str resource_name: The name of the resource.
        :param SentryTeamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryTeamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryTeamArgs.__new__(SentryTeamArgs)

            __props__.__dict__["name"] = name
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            __props__.__dict__["slug"] = slug
            __props__.__dict__["has_access"] = None
            __props__.__dict__["internal_id"] = None
            __props__.__dict__["is_member"] = None
            __props__.__dict__["is_pending"] = None
            __props__.__dict__["team_id"] = None
        super(SentryTeam, __self__).__init__(
            'sentry:index/sentryTeam:SentryTeam',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            has_access: Optional[pulumi.Input[bool]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            is_member: Optional[pulumi.Input[bool]] = None,
            is_pending: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            slug: Optional[pulumi.Input[str]] = None,
            team_id: Optional[pulumi.Input[str]] = None) -> 'SentryTeam':
        """
        Get an existing SentryTeam resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] internal_id: The internal ID for this team.
        :param pulumi.Input[str] name: The name of the team.
        :param pulumi.Input[str] organization: The slug of the organization the team should be created for.
        :param pulumi.Input[str] slug: The optional slug for this team.
        :param pulumi.Input[str] team_id: Use `internal_id` instead.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryTeamState.__new__(_SentryTeamState)

        __props__.__dict__["has_access"] = has_access
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["is_member"] = is_member
        __props__.__dict__["is_pending"] = is_pending
        __props__.__dict__["name"] = name
        __props__.__dict__["organization"] = organization
        __props__.__dict__["slug"] = slug
        __props__.__dict__["team_id"] = team_id
        return SentryTeam(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="hasAccess")
    def has_access(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "has_access")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this team.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter(name="isMember")
    def is_member(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "is_member")

    @property
    @pulumi.getter(name="isPending")
    def is_pending(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "is_pending")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the team.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the team should be created for.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Output[str]:
        """
        The optional slug for this team.
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter(name="teamId")
    @_utilities.deprecated("""Use `internal_id` instead.""")
    def team_id(self) -> pulumi.Output[str]:
        """
        Use `internal_id` instead.
        """
        return pulumi.get(self, "team_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryKeyArgs', 'SentryKey']

@pulumi.input_type
class SentryKeyArgs:
    def __init__(__self__, *,
                 organization: pulumi.Input[str],
                 project: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 rate_limit_count: Optional[pulumi.Input[int]] = None,
                 rate_limit_window: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a SentryKey resource.
        :param pulumi.Input[str] organization: The slug of the organization the key should be created for.
        :param pulumi.Input[str] project: The slug of the project the key should be created for.
        :param pulumi.Input[str] name: The name of the key.
        :param pulumi.Input[int] rate_limit_count: Number of events that can be reported within the rate limit window.
        :param pulumi.Input[int] rate_limit_window: Length of time that will be considered when checking the rate limit.
        """
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "project", project)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rate_limit_count is not None:
            pulumi.set(__self__, "rate_limit_count", rate_limit_count)
        if rate_limit_window is not None:
            pulumi.set(__self__, "rate_limit_window", rate_limit_window)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the key should be created for.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The slug of the project the key should be created for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="rateLimitCount")
    def rate_limit_count(self) -> Optional[pulumi.Input[int]]:
        """
        Number of events that can be reported within the rate limit window.
        """
        return pulumi.get(self, "rate_limit_count")

    @rate_limit_count.setter
    def rate_limit_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rate_limit_count", value)

    @property
    @pulumi.getter(name="rateLimitWindow")
    def rate_limit_window(self) -> Optional[pulumi.Input[int]]:
        """
        Length of time that will be considered when checking the rate limit.
        """
        return pulumi.get(self, "rate_limit_window")

    @rate_limit_window.setter
    def rate_limit_window(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rate_limit_window", value)


@pulumi.input_type
class _SentryKeyState:
    def __init__(__self__, *,
                 dsn_csp: Optional[pulumi.Input[str]] = None,
                 dsn_public: Optional[pulumi.Input[str]] = None,
                 dsn_secret: Optional[pulumi.Input[str]] = None,
                 is_active: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[int]] = None,
                 public: Optional[pulumi.Input[str]] = None,
                 rate_limit_count: Optional[pulumi.Input[int]] = None,
                 rate_limit_window: Optional[pulumi.Input[int]] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SentryKey resources.
        :param pulumi.Input[str] dsn_csp: DSN for the Content Security Policy (CSP) for the key.
        :param pulumi.Input[str] dsn_public: DSN for the key.
        :param pulumi.Input[bool] is_active: Flag indicating the key is active.
        :param pulumi.Input[str] name: The name of the key.
        :param pulumi.Input[str] organization: The slug of the organization the key should be created for.
        :param pulumi.Input[str] project: The slug of the project the key should be created for.
        :param pulumi.Input[int] project_id: The ID of the project that the key belongs to.
        :param pulumi.Input[str] public: Public key portion of the client key.
        :param pulumi.Input[int] rate_limit_count: Number of events that can be reported within the rate limit window.
        :param pulumi.Input[int] rate_limit_window: Length of time that will be considered when checking the rate limit.
        :param pulumi.Input[str] secret: Secret key portion of the client key.
        """
        if dsn_csp is not None:
            pulumi.set(__self__, "dsn_csp", dsn_csp)
        if dsn_public is not None:
            pulumi.set(__self__, "dsn_public", dsn_public)
        if dsn_secret is not None:
            warnings.warn("""DSN (Deprecated) for the key.""", DeprecationWarning)
            pulumi.log.warn("""dsn_secret is deprecated: DSN (Deprecated) for the key.""")
        if dsn_secret is not None:
            pulumi.set(__self__, "dsn_secret", dsn_secret)
        if is_active is not None:
            pulumi.set(__self__, "is_active", is_active)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public is not None:
            pulumi.set(__self__, "public", public)
        if rate_limit_count is not None:
            pulumi.set(__self__, "rate_limit_count", rate_limit_count)
        if rate_limit_window is not None:
            pulumi.set(__self__, "rate_limit_window", rate_limit_window)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="dsnCsp")
    def dsn_csp(self) -> Optional[pulumi.Input[str]]:
        """
        DSN for the Content Security Policy (CSP) for the key.
        """
        return pulumi.get(self, "dsn_csp")

    @dsn_csp.setter
    def dsn_csp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dsn_csp", value)

    @property
    @pulumi.getter(name="dsnPublic")
    def dsn_public(self) -> Optional[pulumi.Input[str]]:
        """
        DSN for the key.
        """
        return pulumi.get(self, "dsn_public")

    @dsn_public.setter
    def dsn_public(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dsn_public", value)

    @property
    @pulumi.getter(name="dsnSecret")
    @_utilities.deprecated("""DSN (Deprecated) for the key.""")
    def dsn_secret(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dsn_secret")

    @dsn_secret.setter
    def dsn_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dsn_secret", value)

    @property
    @pulumi.getter(name="isActive")
    def is_active(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag indicating the key is active.
        """
        return pulumi.get(self, "is_active")

    @is_active.setter
    def is_active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_active", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the key should be created for.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the project the key should be created for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the project that the key belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def public(self) -> Optional[pulumi.Input[str]]:
        """
        Public key portion of the client key.
        """
        return pulumi.get(self, "public")

    @public.setter
    def public(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "public", value)

    @property
    @pulumi.getter(name="rateLimitCount")
    def rate_limit_count(self) -> Optional[pulumi.Input[int]]:
        """
        Number of events that can be reported within the rate limit window.
        """
        return pulumi.get(self, "rate_limit_count")

    @rate_limit_count.setter
    def rate_limit_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rate_limit_count", value)

    @property
    @pulumi.getter(name="rateLimitWindow")
    def rate_limit_window(self) -> Optional[pulumi.Input[int]]:
        """
        Length of time that will be considered when checking the rate limit.
        """
        return pulumi.get(self, "rate_limit_window")

    @rate_limit_window.setter
    def rate_limit_window(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rate_limit_window", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        Secret key portion of the client key.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


class SentryKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 rate_limit_count: Optional[pulumi.Input[int]] = None,
                 rate_limit_window: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Sentry Key resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a key
        default = sentry.SentryKey("default",
            organization="my-organization",
            project="web-app",
            name="My Key")
        ```

        ## Import

        import using the organization, project slugs and key id from the URL:

        https://sentry.io/settings/[org-slug]/projects/[project-slug]/keys/[key-id]/

        ```sh
        $ pulumi import sentry:index/sentryKey:SentryKey default org-slug/project-slug/key-id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the key.
        :param pulumi.Input[str] organization: The slug of the organization the key should be created for.
        :param pulumi.Input[str] project: The slug of the project the key should be created for.
        :param pulumi.Input[int] rate_limit_count: Number of events that can be reported within the rate limit window.
        :param pulumi.Input[int] rate_limit_window: Length of time that will be considered when checking the rate limit.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Key resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a key
        default = sentry.SentryKey("default",
            organization="my-organization",
            project="web-app",
            name="My Key")
        ```

        ## Import

        import using the organization, project slugs and key id from the URL:

        https://sentry.io/settings/[org-slug]/projects/[project-slug]/keys/[key-id]/

        ```sh
        $ pulumi import sentry:index/sentryKey:SentryKey default org-slug/project-slug/key-id
        ```

        :param str resource_name: The name of the resource.
        :param SentryKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 rate_limit_count: Optional[pulumi.Input[int]] = None,
                 rate_limit_window: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryKeyArgs.__new__(SentryKeyArgs)

            __props__.__dict__["name"] = name
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["rate_limit_count"] = rate_limit_count
            __props__.__dict__["rate_limit_window"] = rate_limit_window
            __props__.__dict__["dsn_csp"] = None
            __props__.__dict__["dsn_public"] = None
            __props__.__dict__["dsn_secret"] = None
            __props__.__dict__["is_active"] = None
            __props__.__dict__["project_id"] = None
            __props__.__dict__["public"] = None
            __props__.__dict__["secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["dsnSecret", "secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SentryKey, __self__).__init__(
            'sentry:index/sentryKey:SentryKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dsn_csp: Optional[pulumi.Input[str]] = None,
            dsn_public: Optional[pulumi.Input[str]] = None,
            dsn_secret: Optional[pulumi.Input[str]] = None,
            is_active: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[int]] = None,
            public: Optional[pulumi.Input[str]] = None,
            rate_limit_count: Optional[pulumi.Input[int]] = None,
            rate_limit_window: Optional[pulumi.Input[int]] = None,
            secret: Optional[pulumi.Input[str]] = None) -> 'SentryKey':
        """
        Get an existing SentryKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dsn_csp: DSN for the Content Security Policy (CSP) for the key.
        :param pulumi.Input[str] dsn_public: DSN for the key.
        :param pulumi.Input[bool] is_active: Flag indicating the key is active.
        :param pulumi.Input[str] name: The name of the key.
        :param pulumi.Input[str] organization: The slug of the organization the key should be created for.
        :param pulumi.Input[str] project: The slug of the project the key should be created for.
        :param pulumi.Input[int] project_id: The ID of the project that the key belongs to.
        :param pulumi.Input[str] public: Public key portion of the client key.
        :param pulumi.Input[int] rate_limit_count: Number of events that can be reported within the rate limit window.
        :param pulumi.Input[int] rate_limit_window: Length of time that will be considered when checking the rate limit.
        :param pulumi.Input[str] secret: Secret key portion of the client key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryKeyState.__new__(_SentryKeyState)

        __props__.__dict__["dsn_csp"] = dsn_csp
        __props__.__dict__["dsn_public"] = dsn_public
        __props__.__dict__["dsn_secret"] = dsn_secret
        __props__.__dict__["is_active"] = is_active
        __props__.__dict__["name"] = name
        __props__.__dict__["organization"] = organization
        __props__.__dict__["project"] = project
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["public"] = public
        __props__.__dict__["rate_limit_count"] = rate_limit_count
        __props__.__dict__["rate_limit_window"] = rate_limit_window
        __props__.__dict__["secret"] = secret
        return SentryKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dsnCsp")
    def dsn_csp(self) -> pulumi.Output[str]:
        """
        DSN for the Content Security Policy (CSP) for the key.
        """
        return pulumi.get(self, "dsn_csp")

    @property
    @pulumi.getter(name="dsnPublic")
    def dsn_public(self) -> pulumi.Output[str]:
        """
        DSN for the key.
        """
        return pulumi.get(self, "dsn_public")

    @property
    @pulumi.getter(name="dsnSecret")
    @_utilities.deprecated("""DSN (Deprecated) for the key.""")
    def dsn_secret(self) -> pulumi.Output[str]:
        return pulumi.get(self, "dsn_secret")

    @property
    @pulumi.getter(name="isActive")
    def is_active(self) -> pulumi.Output[bool]:
        """
        Flag indicating the key is active.
        """
        return pulumi.get(self, "is_active")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the key.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the key should be created for.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The slug of the project the key should be created for.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[int]:
        """
        The ID of the project that the key belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def public(self) -> pulumi.Output[str]:
        """
        Public key portion of the client key.
        """
        return pulumi.get(self, "public")

    @property
    @pulumi.getter(name="rateLimitCount")
    def rate_limit_count(self) -> pulumi.Output[int]:
        """
        Number of events that can be reported within the rate limit window.
        """
        return pulumi.get(self, "rate_limit_count")

    @property
    @pulumi.getter(name="rateLimitWindow")
    def rate_limit_window(self) -> pulumi.Output[int]:
        """
        Length of time that will be considered when checking the rate limit.
        """
        return pulumi.get(self, "rate_limit_window")

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Output[str]:
        """
        Secret key portion of the client key.
        """
        return pulumi.get(self, "secret")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

baseUrl: Optional[str]
"""
The target Sentry Base API URL in the format `https://[hostname]/api/`. The default value is `https://sentry.io/api/`.
The value must be provided when working with Sentry On-Premise. The value can be sourced from the `SENTRY_BASE_URL`
environment variable.
"""

token: Optional[str]
"""
The authentication token used to connect to Sentry. The value can be sourced from the `SENTRY_AUTH_TOKEN` environment
variable.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetSentryDashboardResult',
    'AwaitableGetSentryDashboardResult',
    'get_sentry_dashboard',
    'get_sentry_dashboard_output',
]

@pulumi.output_type
class GetSentryDashboardResult:
    """
    A collection of values returned by getSentryDashboard.
    """
    def __init__(__self__, id=None, internal_id=None, organization=None, title=None, widgets=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_id and not isinstance(internal_id, str):
            raise TypeError("Expected argument 'internal_id' to be a str")
        pulumi.set(__self__, "internal_id", internal_id)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if widgets and not isinstance(widgets, list):
            raise TypeError("Expected argument 'widgets' to be a list")
        pulumi.set(__self__, "widgets", widgets)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> str:
        """
        The internal ID for this dashboard.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The slug of the organization the dashboard belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def title(self) -> str:
        """
        Dashboard title.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def widgets(self) -> Sequence['outputs.GetSentryDashboardWidgetResult']:
        """
        Dashboard widgets.
        """
        return pulumi.get(self, "widgets")


class AwaitableGetSentryDashboardResult(GetSentryDashboardResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSentryDashboardResult(
            id=self.id,
            internal_id=self.internal_id,
            organization=self.organization,
            title=self.title,
            widgets=self.widgets)


def get_sentry_dashboard(internal_id: Optional[str] = None,
                         organization: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSentryDashboardResult:
    """
    ## Example Usage


    :param str internal_id: The internal ID for this dashboard.
    :param str organization: The slug of the organization the dashboard belongs to.
    """
    __args__ = dict()
    __args__['internalId'] = internal_id
    __args__['organization'] = organization
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('sentry:index/getSentryDashboard:getSentryDashboard', __args__, opts=opts, typ=GetSentryDashboardResult).value

    return AwaitableGetSentryDashboardResult(
        id=pulumi.get(__ret__, 'id'),
        internal_id=pulumi.get(__ret__, 'internal_id'),
        organization=pulumi.get(__ret__, 'organization'),
        title=pulumi.get(__ret__, 'title'),
        widgets=pulumi.get(__ret__, 'widgets'))
def get_sentry_dashboard_output(internal_id: Optional[pulumi.Input[str]] = None,
                                organization: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSentryDashboardResult]:
    """
    ## Example Usage


    :param str internal_id: The internal ID for this dashboard.
    :param str organization: The slug of the organization the dashboard belongs to.
    """
    __args__ = dict()
    __args__['internalId'] = internal_id
    __args__['organization'] = organization
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('sentry:index/getSentryDashboard:getSentryDashboard', __args__, opts=opts, typ=GetSentryDashboardResult)
    return __ret__.apply(lambda __response__: GetSentryDashboardResult(
        id=pulumi.get(__response__, 'id'),
        internal_id=pulumi.get(__response__, 'internal_id'),
        organization=pulumi.get(__response__, 'organization'),
        title=pulumi.get(__response__, 'title'),
        widgets=pulumi.get(__response__, 'widgets')))
